EventHandler

Struct EventHandler 

pub(crate) struct EventHandler {
    rx: UnboundedReceiver<Message>,
    tx: UnboundedSender<Message>,
    cmd_tx: UnboundedSender<RadioCommand>,
    cmd_rx: Option<UnboundedReceiver<RadioCommand>>,
}
Merges terminal key events with messages from background tasks.

Fields

rx: UnboundedReceiver<Message>tx: UnboundedSender<Message>cmd_tx: UnboundedSender<RadioCommand>cmd_rx: Option<UnboundedReceiver<RadioCommand>>

Implementations

Source

impl EventHandler

pub(crate) fn new() -> Self

Create a new event handler with internal message and command channels.

pub(crate) fn sender(&self) -> UnboundedSender<Message>

Returns a sender that background tasks can use to push messages.

pub(crate) fn command_sender(&self) -> UnboundedSender<RadioCommand>

Returns a sender the app can use to send commands to the radio task.

pub(crate) const fn take_command_receiver( &mut self, ) -> UnboundedReceiver<RadioCommand>

Takes the command receiver (can only be called once).

Panics

Panics if the command receiver has already been taken.

pub(crate) async fn next(&mut self) -> Message

Wait for the next message from any source (terminal input or background tasks).