pub(crate) struct EventHandler {
rx: UnboundedReceiver<Message>,
tx: UnboundedSender<Message>,
cmd_tx: UnboundedSender<RadioCommand>,
cmd_rx: Option<UnboundedReceiver<RadioCommand>>,
}Expand description
Merges terminal key events with messages from background tasks.
Fields
rx: UnboundedReceiver<Message>tx: UnboundedSender<Message>cmd_tx: UnboundedSender<RadioCommand>cmd_rx: Option<UnboundedReceiver<RadioCommand>>Implementations
Sourceimpl EventHandler
impl EventHandler
Sourcepub(crate) fn new() -> Self
pub(crate) fn new() -> Self
Create a new event handler with internal message and command channels.
Sourcepub(crate) fn sender(&self) -> UnboundedSender<Message>
pub(crate) fn sender(&self) -> UnboundedSender<Message>
Returns a sender that background tasks can use to push messages.
Sourcepub(crate) fn command_sender(&self) -> UnboundedSender<RadioCommand>
pub(crate) fn command_sender(&self) -> UnboundedSender<RadioCommand>
Returns a sender the app can use to send commands to the radio task.
Sourcepub(crate) const fn take_command_receiver(
&mut self,
) -> UnboundedReceiver<RadioCommand>
pub(crate) const fn take_command_receiver( &mut self, ) -> UnboundedReceiver<RadioCommand>
Takes the command receiver (can only be called once).
Panics
Panics if the command receiver has already been taken.